summaryrefslogtreecommitdiffstats
path: root/pykdeconfig.py
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-03 22:23:44 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-03 22:23:44 -0600
commit203ba231d0276943aae36111f9ec1e949f3c6a4c (patch)
treef039f7a5b5fc2da88a96876971bac580d87f6788 /pykdeconfig.py
parentfd35f4a8382b7d223bc0325b9ca3f88515778aa0 (diff)
downloadpytde-203ba231d0276943aae36111f9ec1e949f3c6a4c.tar.gz
pytde-203ba231d0276943aae36111f9ec1e949f3c6a4c.zip
Initial TQt conversion
Diffstat (limited to 'pykdeconfig.py')
-rw-r--r--pykdeconfig.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/pykdeconfig.py b/pykdeconfig.py
index 164fb81..5de2e47 100644
--- a/pykdeconfig.py
+++ b/pykdeconfig.py
@@ -25,7 +25,7 @@
import sipconfig, pyqtconfig
# These are installation specific values created when PyQt was configured.
_pkg_config = {
'dist_name': '',
'kde_version': 0x030503,
@@ -36,7 +36,7 @@ _pkg_config = {
'kdeincdir': '/opt/trinity/include',
'kdelibdir': '/opt/trinity/lib',
'libdir': 'lib',
- 'pykde_kde_sip_flags': '-t ALL -x Qt_STYLE_WINDOWSXP -x Qt_STYLE_INTERLACE -x Qt_STYLE_WINDOWSXP -x Qt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t Qt_3_3_6 -t KDE_3_5_3',
+ 'pykde_kde_sip_flags': '-t ALL -x TQt_STYLE_WINDOWSXP -x TQt_STYLE_INTERLACE -x TQt_STYLE_WINDOWSXP -x TQt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t TQt_3_3_6 -t KDE_3_5_3',
'pykde_mod_dir': '/usr/lib/python2.5/site-packages',
'pykde_modules': 'dcop tdecore tdefx tdeui kio kresources kabc kutils kfile kparts khtml kspell tdeprint kmdi',
'pykde_sip_dir': '/usr/share/sip',
@@ -48,7 +48,7 @@ _default_macros = None
class Configuration(pyqtconfig.Configuration):
"""The class that represents PyQt configuration values.
"""
def __init__(self, sub_cfg=None):
"""Initialise an instance of the class.
@@ -66,7 +66,7 @@ class Configuration(pyqtconfig.Configuration):
pyqtconfig.Configuration.__init__(self, cfg)
-class DCOPModuleMakefile(pyqtconfig.QtModuleMakefile):
+class DCOPModuleMakefile(pyqtconfig.TQtModuleMakefile):
"""The Makefile class for modules that %Import DCOP.
"""
def finalise(self):
@@ -79,7 +79,7 @@ class DCOPModuleMakefile(pyqtconfig.QtModuleMakefile):
self.LIBDIR.append(self.config.pykde_lib_dir)
self.extra_libs.append(self.module_as_lib("DCOP"))
- pyqtconfig.QtModuleMakefile.finalise(self)
+ pyqtconfig.TQtModuleMakefile.finalise(self)
class KdecoreModuleMakefile(DCOPModuleMakefile):
"""The Makefile class for modules that %Import tdecore.
@@ -25,7 +25,7 @@
import sipconfig, pyqtconfig
-# These are installation specific values created when PyQt was configured.
+# These are installation specific values created when PyTQt was configured.
_pkg_config = {
'dist_name': '',
@@ -48,7 +48,7 @@ _default_macros = None
class Configuration(pyqtconfig.Configuration):
- """The class that represents PyQt configuration values.
+ """The class that represents PyTQt configuration values.
"""
def __init__(self, sub_cfg=None):